==> epiphany-1.6.4.tar.bz2: epiphany-1.6.4/embed/mozilla/EphySidebar.h <==
/*
 *  Copyright (C) 2002 Philip Langdale
 *  Copyright (C) 2004 Crispin Flowerday
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * 
 *  $Id: EphySidebar.h,v 1.1 2005/01/01 21:32:57 crispin Exp $
 */

#ifndef EPHY_SIDEBAR_H
#define EPHY_SIDEBAR_H

#include <nsISidebar.h>
#include <nsIClassInfo.h>
#include <nsError.h>

#define EPHY_SIDEBAR_CLASSNAME \
 "Epiphany's Sidebar Implementation"

#define EPHY_SIDEBAR_CID \
{  /* {50f13159-f9b9-44b3-b18e-6ee5d85a202a} */      \
    0x50f13159,                                      \
    0xf9b9,                                          \
    0x44b3,                                          \
    {0xb1, 0x8e, 0x6e, 0xe5, 0xd8, 0x5a, 0x20, 0x2a} \
}

class EphySidebar : public nsISidebar, nsIClassInfo
{
  public:
	NS_DECL_ISUPPORTS
	NS_DECL_NSICLASSINFO
	NS_DECL_NSISIDEBAR

	EphySidebar();
	virtual ~EphySidebar();
  private:
};

#endif /* ! EPHY_SIDEBAR_H */

==> epiphany-1.9.2.tar.bz2: epiphany-1.9.2/embed/mozilla/EphySidebar.h <==
/*
 *  Copyright (C) 2002 Philip Langdale
 *  Copyright (C) 2004 Crispin Flowerday
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * 
 *  $Id: EphySidebar.h,v 1.2 2005/05/01 14:04:24 chpe Exp $
 */

#ifndef EPHY_SIDEBAR_H
#define EPHY_SIDEBAR_H

#include <nsISidebar.h>
#include <nsIClassInfo.h>
#include <nsError.h>

#define EPHY_SIDEBAR_CLASSNAME \
 "Epiphany's Sidebar Implementation"

#define EPHY_SIDEBAR_CID \
{  /* {50f13159-f9b9-44b3-b18e-6ee5d85a202a} */      \
    0x50f13159,                                      \
    0xf9b9,                                          \
    0x44b3,                                          \
    {0xb1, 0x8e, 0x6e, 0xe5, 0xd8, 0x5a, 0x20, 0x2a} \
}

class EphySidebar : public nsISidebar
{
  public:
	NS_DECL_ISUPPORTS
	NS_DECL_NSISIDEBAR

	EphySidebar();
	virtual ~EphySidebar();
  private:
};

#endif /* ! EPHY_SIDEBAR_H */
